@@ -7,7 +7,6 @@ import typing
 from sys import maxsize
 
 from ruamel.yaml import YAML
-from ruamel.yaml.error import YAMLError
 
 
 def _process_single_document(document: str, yaml: YAML) -> str:
@@ -44,7 +43,7 @@ def pretty_format_yaml(argv: typing.Optional[typing.List[str]] = None) -> int:
         "--indent",
         type=int,
         default="2",
-        help=("The number of indent spaces or a string to be used as delimiter" ' for indentation level e.g. 4 or "\t" (Default: 2)'),
+        help="The number of indent spaces or a string to be used as delimiter for indentation level e.g. 4 or '\t' (Default: 2)",
     )
     parser.add_argument(
         "--preserve-quotes",
@@ -52,6 +51,16 @@ def pretty_format_yaml(argv: typing.Optional[typing.List[str]] = None) -> int:
         dest="preserve_quotes",
         help="Keep existing string quoting",
     )
+    parser.add_argument(
+        "--line-width",
+        type=int,
+        default=maxsize,
+        dest="line_width",
+        help=(
+            "Max line length on the generated file. NOTE: As far as we attempt to"
+            " enforce the limit we cannot guarantee that it is always possible"
+        ),
+    )
 
     parser.add_argument("filenames", nargs="*", help="Filenames to fix")
     args = parser.parse_args(argv)
@@ -62,7 +71,7 @@ def pretty_format_yaml(argv: typing.Optional[typing.List[str]] = None) -> int:
     yaml.indent = args.indent
     yaml.preserve_quotes = args.preserve_quotes
     # Prevent ruamel.yaml to wrap yaml lines
-    yaml.width = maxsize  # type: ignore  # mypy recognise yaml.width as None
+    yaml.width = args.line_width  # type: ignore  # mypy recognise yaml.width as None
 
     separator = "---\n"
 
@@ -103,11 +112,9 @@ def pretty_format_yaml(argv: typing.Optional[typing.List[str]] = None) -> int:
                         output_file.write(str(pretty_content))
 
                 status = 1
-        except YAMLError:  # pragma: no cover
+        except BaseException as e:  # pragma: no cover
             print(
-                "Input File {} is not a valid YAML file, consider using check-yaml".format(
-                    yaml_file,
-                ),
+                "Input File {} is not a valid YAML file, consider using check-yaml: {}".format(yaml_file, e),
             )
             return 1
 
